@@ -19,6 +19,8 @@ import os
 import unittest
 import inspect
 
+import six
+
 from bandit.core import constants as C
 from bandit.core import manager as b_manager
 from bandit.core import test_set as b_test_set
@@ -90,7 +92,7 @@ class FunctionalTests(unittest.TestCase):
 
     def test_crypto_md5(self):
         '''Test the `hashlib.md5` example.'''
-        expect = {'SEVERITY': {'MEDIUM': 5}, 'CONFIDENCE': {'HIGH': 5}}
+        expect = {'SEVERITY': {'MEDIUM': 4}, 'CONFIDENCE': {'HIGH': 4}}
         self.check_example('crypto-md5.py', expect)
 
     def test_eval(self):
@@ -100,8 +102,14 @@ class FunctionalTests(unittest.TestCase):
 
     def test_exec(self):
         '''Test the `exec` example.'''
-        expect = {'SEVERITY': {'MEDIUM': 2}, 'CONFIDENCE': {'HIGH': 2}}
-        self.check_example('exec.py', expect)
+        filename = 'exec-{}.py'
+        if six.PY2:
+            filename = filename.format('py2')
+            expect = {'SEVERITY': {'MEDIUM': 2}, 'CONFIDENCE': {'HIGH': 2}}
+        else:
+            filename = filename.format('py3')
+            expect = {'SEVERITY': {'MEDIUM': 1}, 'CONFIDENCE': {'HIGH': 1}}
+        self.check_example(filename, expect)
 
     def test_exec_as_root(self):
         '''Test for the `run_as_root=True` keyword argument.'''
@@ -114,8 +122,8 @@ class FunctionalTests(unittest.TestCase):
         self.check_example('hardcoded-passwords.py', expect)
 
     def test_hardcoded_tmp(self):
-        '''Test for hard-coded /tmp.'''
-        expect = {'SEVERITY': {'MEDIUM': 1}, 'CONFIDENCE': {'MEDIUM': 1}}
+        '''Test for hard-coded /tmp, /var/tmp, /dev/shm'''
+        expect = {'SEVERITY': {'MEDIUM': 3}, 'CONFIDENCE': {'MEDIUM': 3}}
         self.check_example('hardcoded-tmp.py', expect)
 
     def test_httplib_https(self):
@@ -153,7 +161,7 @@ class FunctionalTests(unittest.TestCase):
 
     def test_multiline_str(self):
         '''Test docstrings and multi-line strings are handled properly.'''
-        expect = {'SEVERITY': {'MEDIUM': 2}, 'CONFIDENCE': {'MEDIUM': 2}}
+        expect = {'SEVERITY': {'MEDIUM': 3}, 'CONFIDENCE': {'MEDIUM': 3}}
         self.check_example('multiline-str.py', expect)
 
     def test_mktemp(self):
@@ -173,10 +181,19 @@ class FunctionalTests(unittest.TestCase):
 
     def test_os_chmod(self):
         '''Test setting file permissions.'''
-        expect = {
-            'SEVERITY': {'MEDIUM': 2, 'HIGH': 9},
-            'CONFIDENCE': {'HIGH': 10, 'MEDIUM': 1}
-        }
+        filename = 'os-chmod-{}.py'
+        if six.PY2:
+            filename = filename.format('py2')
+            expect = {
+                'SEVERITY': {'MEDIUM': 2, 'HIGH': 9},
+                'CONFIDENCE': {'HIGH': 10, 'MEDIUM': 1}
+            }
+        else:
+            filename = filename.format('py3')
+            expect = {
+                'SEVERITY': {'MEDIUM': 2, 'HIGH': 9},
+                'CONFIDENCE': {'HIGH': 10, 'MEDIUM': 1}
+            }
         self.check_example('os-chmod.py', expect)
 
     def test_os_exec(self):
@@ -219,7 +236,7 @@ class FunctionalTests(unittest.TestCase):
 
     def test_random_module(self):
         '''Test for the `random` module.'''
-        expect = {'SEVERITY': {'LOW': 3}, 'CONFIDENCE': {'HIGH': 3}}
+        expect = {'SEVERITY': {'LOW': 6}, 'CONFIDENCE': {'HIGH': 6}}
         self.check_example('random_module.py', expect)
 
     def test_requests_ssl_verify_disabled(self):
@@ -232,15 +249,12 @@ class FunctionalTests(unittest.TestCase):
         expect = {'SEVERITY': {'LOW': 5}, 'CONFIDENCE': {'HIGH': 5}}
         self.check_example('skip.py', expect)
 
-    def test_sql_statements_with_sqlalchemy(self):
+    def test_sql_statements(self):
         '''Test for SQL injection through string building.'''
-        expect = {'SEVERITY': {'LOW': 4}, 'CONFIDENCE': {'LOW': 4}}
-        self.check_example('sql_statements_with_sqlalchemy.py', expect)
-
-    def test_sql_statements_without_sql_alchemy(self):
-        '''Test for SQL injection without SQLAlchemy.'''
-        expect = {'SEVERITY': {'MEDIUM': 4}, 'CONFIDENCE': {'LOW': 4}}
-        self.check_example('sql_statements_without_sql_alchemy.py', expect)
+        expect = {
+            'SEVERITY': {'MEDIUM': 11},
+            'CONFIDENCE': {'LOW': 6, 'MEDIUM': 5}}
+        self.check_example('sql_statements.py', expect)
 
     def test_ssl_insecure_version(self):
         '''Test for insecure SSL protocol versions.'''
@@ -348,3 +362,44 @@ class FunctionalTests(unittest.TestCase):
         expect = {'SEVERITY': {'LOW': 1},
                   'CONFIDENCE': {'HIGH': 1}}
         self.check_example('assert.py', expect)
+
+    def test_paramiko_injection(self):
+        '''Test paramiko command execution.'''
+        expect = {'SEVERITY': {'MEDIUM': 2},
+                  'CONFIDENCE': {'MEDIUM': 2}}
+        self.check_example('paramiko_injection.py', expect)
+
+    def test_partial_path(self):
+        '''Test process spawning with partial file paths.'''
+        expect = {'SEVERITY': {'LOW': 9},
+                  'CONFIDENCE': {'HIGH': 9}}
+
+        self.check_example('partial_path_process.py', expect)
+
+    def test_try_except_pass(self):
+        '''Test try, except pass detection.'''
+        expect = {'SEVERITY': {'LOW': 3},
+                  'CONFIDENCE': {'HIGH': 3}}
+
+        self.check_example('try_except_pass.py', expect)
+
+    def test_multiline_code(self):
+        '''Test issues in multiline statements return code as expected.'''
+        self.run_example('multiline-str.py')
+        self.assertEqual(0, len(self.b_mgr.b_rs.skipped))
+        self.assertEqual(1, len(self.b_mgr.files_list))
+        self.assertTrue(self.b_mgr.files_list[0].endswith('multiline-str.py'))
+        issues = self.b_mgr.b_rs._get_issue_list()
+        self.assertEqual(3, len(issues))
+        self.assertTrue(
+            issues[0]['filename'].endswith('examples/multiline-str.py')
+        )
+        self.assertEqual(4, issues[0]['line_number'])
+        self.assertEqual(range(2, 7), issues[0]['line_range'])
+        self.assertIn('/tmp', issues[0]['code'])
+        self.assertEqual(18, issues[1]['line_number'])
+        self.assertEqual(range(16, 19), issues[1]['line_range'])
+        self.assertIn('/tmp', issues[1]['code'])
+        self.assertEqual(23, issues[2]['line_number'])
+        self.assertEqual(range(22, 31), issues[2]['line_range'])
+        self.assertIn('/tmp', issues[2]['code'])
